
#ifndef QT5GSETTINGS_EXPORT_H
#define QT5GSETTINGS_EXPORT_H

#ifdef QT5GSETTINGS_STATIC_DEFINE
#  define QT5GSETTINGS_EXPORT
#  define QT5GSETTINGS_NO_EXPORT
#else
#  ifndef QT5GSETTINGS_EXPORT
#    ifdef LIRI_BUILD_QT5GSETTINGS_LIB
        /* We are building this library */
#      define QT5GSETTINGS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define QT5GSETTINGS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef QT5GSETTINGS_NO_EXPORT
#    define QT5GSETTINGS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef QT5GSETTINGS_DEPRECATED
#  define QT5GSETTINGS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef QT5GSETTINGS_DEPRECATED_EXPORT
#  define QT5GSETTINGS_DEPRECATED_EXPORT QT5GSETTINGS_EXPORT QT5GSETTINGS_DEPRECATED
#endif

#ifndef QT5GSETTINGS_DEPRECATED_NO_EXPORT
#  define QT5GSETTINGS_DEPRECATED_NO_EXPORT QT5GSETTINGS_NO_EXPORT QT5GSETTINGS_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef QT5GSETTINGS_NO_DEPRECATED
#    define QT5GSETTINGS_NO_DEPRECATED
#  endif
#endif

#endif /* QT5GSETTINGS_EXPORT_H */
