/* This file was generated by liri_add_module(). */

#ifndef LIRIQT5GSETTINGS_VERSION_H
#define LIRIQT5GSETTINGS_VERSION_H

#define LIRIQT5GSETTINGS_VERSION_STR "1.3.0"

#define LIRIQT5GSETTINGS_VERSION ((1<<16)|(3<<8)|(0)))

#endif // LIRIQT5GSETTINGS_VERSION_H
